#!/etc/opt/openit/perl


use strict;
use Getopt::Long;

my $opt_debug;
unless ( GetOptions( "debug"        => \ $opt_debug ) ){}

_main();

sub _main(){
	my $usergroupsfilter = `. /tmp/openit-cfg-shenv;echo \$CONFIG_DIR/filtrator/licenseevents-usergroups.conf`;
	chomp $usergroupsfilter;
	
	if ( -e $usergroupsfilter ) {
		INFO( "Running update on $usergroupsfilter ");
		_update_filter( $usergroupsfilter );
	} else {
		INFO( "File $usergroupsfilter doesn't exist" );
		return -1;
	}
	
}

sub _update_filter {

    my ($filter) = @_;
	chomp $filter;
    my @lines = _read_file( $filter );

    # Check that filter update is not already present
    if ( grep {/Threshold:remove-zero-group/} @lines ) {
		print "Filter '$filter' already updated\n";
		return;
    }
	
	my $ind = 0;
	$ind = locateLine($ind , "filter-process" , \@lines );
	$ind = locateLine($ind , "Duplicate:usergroups" , \@lines );
	$ind+=2;
	
	my @insert = (
"							Threshold:remove-zero-group()=\"\"\n",
"							{\n" );
	
	splice @lines, $ind, 0, @insert;
	
	$ind = locateLine($ind , "filter-defs" , \@lines );
	splice @lines, $ind-1, 0, "	}\n";
	
	$ind = 0;
	$ind = locateLine($ind , "filter-process" , \@lines );
	$ind = locateLine($ind , "filter-defs" , \@lines );
	$ind+=2;
	
	@insert = 
("
 		Threshold:remove-zero-group()=\"\"
		{
			active(Bool)=\"false\"{}
			filter(String)=\"Threshold\"{}
			index(String)=\"var9\"{}
			value(String)=\"' '\"{}
			method(String)=\"sne\"{}
		} 
" );


	splice @lines, $ind, 0, @insert;
	_save_filter( $filter ,@lines );
	
}


sub locateLine{
	my ( $start , $find , $lines_ref ) = (@_);
	
	#found nothing
	if (( !grep /$find/ , @$lines_ref )){
		return 0;
	}
	
	my ( $index )= grep { @$lines_ref[$_] =~ /$find/ } $start ..@$lines_ref;
	DEBUG( "Found: @$lines_ref[$index] $index $find");
	return $index;
	
}

sub _read_file
{
	my ($cfg) = @_;
	DEBUG( "Reading $cfg " );
	open(IN, "$cfg") || die "Error: Unable to read cfg '$cfg'!\n";
	my @lines = <IN>;
	close(IN);
	return @lines;
}

sub _save_filter
{
	my ( $cfg, @lines ) = @_; 
	
	my $old = "$cfg.old";
	my $new = "$cfg.new";
	
	open(OUT, ">$new") || die "Error: Can't write new cfg '$new'!\n";
	print OUT @lines;
	close(OUT);

	if( ! rename($cfg, $old)) {
		die "Error: Unable to previous config to '$old'!\n";
	}

	if( ! rename($new, $cfg)) {
		die "Error: Unable to rename new config to '$cfg'!\n";
	}
}


sub DEBUG 
{
	my ($msg) = @_;
	if ( $opt_debug )
	{
		print ( "DEBUG: $msg\n" );
	}
}

sub INFO 
{
	my ($msg) = @_;
	print ( "--  $msg\n" );
}
